<?php

/**
 * @file
 * Contains \Drupal\mail\Entity\MailMessage.
 */

namespace Drupal\mail\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\mail\MailMessageInterface;

/**
 * Defines the Mail message entity.
 *
 * @ConfigEntityType(
 *   id = "mail_message",
 *   label = @Translation("Mail message"),
 *   handlers = {
 *     "list_builder" = "Drupal\mail\MailMessageListBuilder",
 *     "form" = {
 *       "edit" = "Drupal\mail\Form\MailMessageForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\mail\MailMessageHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "mail_message",
 *   admin_permission = "administer mail messages",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/system/mail/{mail_message}",
 *     "edit-form" = "/admin/config/system/mail/{mail_message}/edit",
 *     "collection" = "/admin/config/system/mail"
 *   }
 * )
 */
class MailMessage extends ConfigEntityBase implements ConfigEntityInterface, MailMessageInterface {

  /**
   * The Mail message ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Mail message label.
   *
   * @var string
   */
  protected $label;

  /**
   * {@inheritdoc}
   */
  public function getSubject() {
    return $this->subject;
  }

  /**
   * {@inheritdoc}
   */
  public function getBody() {
    return $this->body;
  }

  /**
   * {@inheritdoc}
   */
  public function getMailBackendPluginID() {
    return $this->mail_backend;
  }

  /**
   * {@inheritdoc}
   */
  public function getMailProcessorPluginID() {
    return $this->message_processor;
  }

  // TODO: plugin dependencies.

}
